@@ -1,6 +1,6 @@
 /*
   The oSIP library implements the Session Initiation Protocol (SIP -rfc3261-)
-  Copyright (C) 2001,2002,2003,2004  Aymeric MOIZARD jack@atosc.org
+  Copyright (C) 2001,2002,2003,2004,2005,2006,2007 Aymeric MOIZARD jack@atosc.org
   
   This library is free software; you can redistribute it and/or
   modify it under the terms of the GNU Lesser General Public
@@ -42,8 +42,7 @@
  */
 
 #ifdef __cplusplus
-extern "C"
-{
+extern "C" {
 #endif
 
 #ifndef DOXYGEN
@@ -51,48 +50,45 @@ extern "C"
  * Structure for referencing a node in a osip_list_t element.
  * @var __node_t
  */
-  typedef struct __node __node_t;
+	typedef struct __node __node_t;
 
 /**
  * Structure for referencing a node in a osip_list_t element.
  * @struct __node
  */
-  struct __node
-  {
-    void *next;                 /**< next __node_t containing element */
-    void *element;              /**< element in Current node */
-  };
+	struct __node {
+		__node_t *next;				/**< next __node_t containing element */
+		void *element;			/**< element in Current node */
+	};
 #endif
 
 /**
  * Structure for referencing a list of elements.
  * @var osip_list_t
  */
-  typedef struct osip_list osip_list_t;
+	typedef struct osip_list osip_list_t;
 
-/* added by bennewit@cs.tu-berlin.de */
-  typedef struct
-  {
-    __node_t *actual;
-    __node_t **prev;
-    osip_list_t *li;
-    int pos;
-  } osip_list_iterator_t;
+/**
+ * Structure used to iterate list.
+ * @var osip_list_iterator_t
+ */
+	typedef struct {
+		__node_t *actual;
+		__node_t **prev;
+		osip_list_t *li;
+		int pos;
+	} osip_list_iterator_t;
 
 /**
  * Structure for referencing a list of elements.
  * @struct osip_list
  */
-  struct osip_list
-  {
+	struct osip_list {
 
-    int nb_elt;         /**< Number of element in the list */
-    __node_t *node;     /**< Next node containing element  */
+		int nb_elt;		/**< Number of element in the list */
+		__node_t *node;	/**< Next node containing element  */
 
-  };
-
-/* added by bennewit@cs.tu-berlin.de */
-#define osip_list_iterator_has_elem( it ) ( 0 != (it).actual && (it).pos < (it).li->nb_elt )
+	};
 
 /**
  * Initialise a osip_list_t element.
@@ -103,62 +99,83 @@ extern "C"
  * if you want to use osip_list_free().
  * @param li The element to initialise.
  */
-  int osip_list_init (osip_list_t * li);
+	int osip_list_init(osip_list_t * li);
 /**
  * Free a list of element.
  * Each element will be free with the method given as the second parameter.
  * @param li The element to work on.
  * @param free_func The method that is able to release one element of the list.
  */
-  void osip_list_special_free (osip_list_t * li, void *(*free_func) (void *));
+	void osip_list_special_free(osip_list_t * li, void (*free_func) (void *));
+/**
+ * Clone a list of element.
+ * Each element will be cloned with the method given as the second parameter.
+ * @param src The element to work on.
+ * @param dst The element to work on.
+ * @param clone_func The method that is able to release one element of the list.
+ */
+	int osip_list_clone(const osip_list_t * src, osip_list_t * dst,
+						int (*clone_func) (void *, void **));
 /**
  * Free a list of element where elements are pointer to 'char'.
  * @param li The element to work on.
  */
-  void osip_list_ofchar_free (osip_list_t * li);
+	void osip_list_ofchar_free(osip_list_t * li);
 /**
  * Get the size of a list of element.
  * @param li The element to work on.
  */
-  int osip_list_size (const osip_list_t * li);
+	int osip_list_size(const osip_list_t * li);
 /**
  * Check if the end of list is detected .
  * @param li The element to work on.
  * @param pos The index of the possible element.
  */
-  int osip_list_eol (const osip_list_t * li, int pos);
+	int osip_list_eol(const osip_list_t * li, int pos);
 /**
  * Add an element in a list.
  * @param li The element to work on.
  * @param element The pointer on the element to add.
  * @param pos the index of the element to add. (or -1 to append the element at the end)
  */
-  int osip_list_add (osip_list_t * li, void *element, int pos);
+	int osip_list_add(osip_list_t * li, void *element, int pos);
 /**
  * Get an element from a list.
  * @param li The element to work on.
  * @param pos the index of the element to get.
  */
-  void *osip_list_get (const osip_list_t * li, int pos);
+	void *osip_list_get(const osip_list_t * li, int pos);
 /**
  * Remove an element from a list.
  * @param li The element to work on.
  * @param pos the index of the element to remove.
  */
-  int osip_list_remove (osip_list_t * li, int pos);
+	int osip_list_remove(osip_list_t * li, int pos);
 
-/* added by bennewit@cs.tu-berlin.de */
-  void *osip_list_get_first (osip_list_t * li, osip_list_iterator_t * it);
-/* added by bennewit@cs.tu-berlin.de */
-  void *osip_list_get_next (osip_list_iterator_t * it);
-/* added by bennewit@cs.tu-berlin.de */
-  void *osip_list_iterator_remove (osip_list_iterator_t * it);
+/**
+ * Check current iterator state.
+ * @param it The element to work on.
+ */
+#define osip_list_iterator_has_elem( it ) ( 0 != (it).actual && (it).pos < (it).li->nb_elt )
+/**
+ * Get first iterator from list.
+ * @param li The element to work on.
+ * @param it The iterator.
+ */
+	void *osip_list_get_first(osip_list_t * li, osip_list_iterator_t * it);
+/**
+ * GEt next iterator.
+ * @param it The element to work on.
+ */
+	void *osip_list_get_next(osip_list_iterator_t * it);
+/**
+ * Remove current iterator.
+ * @param it The element to work on.
+ */
+	void *osip_list_iterator_remove(osip_list_iterator_t * it);
 
 #ifdef __cplusplus
 }
 #endif
-
-
 /** @} */
-
 #endif
